#
# spec file for package IPython
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           IPython
BuildRequires:  python-devel
Version:        3.2.2
Release:        4.3
Source0:        https://pypi.python.org/packages/source/i/ipython/ipython-%{version}.tar.gz
Source1:        ipython-icons.tar.xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Url:            http://ipython.scipy.org/
Summary:        An Enhanced Interactive Python Shell
License:        BSD-3-Clause
Group:          Development/Languages/Python
BuildArch:      noarch
BuildRequires:  python
BuildRequires:  python-setuptools
BuildRequires:  python-Cython
BuildRequires:  python-curses
BuildRequires:  python-nose >= 0.10.1
BuildRequires:  python-opengl
BuildRequires:  python-pexpect
BuildRequires:  python-pymongo
BuildRequires:  python-pyzmq-devel >= 2.1.11
%if 0%{?suse_version} != 1315 
BuildRequires:  python-wxWidgets
%endif
%if 0%{?suse_version}
%py_requires
BuildRequires:  fdupes
BuildRequires:  update-desktop-files
%endif
Requires:       python-Jinja2
Requires:       python-pexpect
Requires:       python-pyzmq >= 2.1.11
Recommends:     python-curses
Recommends:     python-pymongo
Recommends:     python-wxWidgets
# qtconsole
BuildRequires:  python-Pygments
BuildRequires:  python-matplotlib
BuildRequires:  python-qt4-devel
Recommends:     python-Pygments
Recommends:     python-matplotlib
Recommends:     python-qt4
# html notebook
BuildRequires:  python-tornado >= 4.0
Recommends:     python-tornado >= 4.0
BuildRequires:  python-mistune >= 0.5
Recommends:     python-mistune >= 0.5
#ipython nbformat
BuildRequires:  python-jsonschema
Requires:       python-jsonschema
#documentation
BuildRequires:  graphviz
BuildRequires:  graphviz-gnome
BuildRequires:  python-Sphinx >= 0.3
BuildRequires:  python-numpydoc
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description
IPython provides a replacement for the interactive python (Python)
interpreter with extra functionality.

Main features:
* Comprehensive object introspection.
* Input history that is persistent across sessions.
* Caching of output results during a session with automatically
   generated references.
* Readline-based name completion.
* Extensible system of 'magic' commands for controlling the
   environment and performing many tasks related either to IPython
   or the operating system.
* Configuration system with easy switching between different setups
   (simpler than changing $PYTHONSTARTUP environment variables every
   time).
* Session logging and reloading.
* Extensible syntax processing for special purpose situations.
* Access to the system shell with user-extensible alias system.
* Easily embeddable in other Python programs.
* Integrated access to the pdb debugger and the Python profiler.


%package doc
Summary:        An Enhanced Interactive Python Shell documentation
Group:          Documentation/Other
Recommends:     %{name} = %{version}

%description doc
IPython provides a replacement for the interactive python (Python)
interpreter with extra functionality.

This package contains comprehensive documentation for IPython in
html format, as well as examples of usage.


%prep
%setup -q -n ipython-%{version}

# Get rid of library shebangs
find . -type f -name "*.py" -exec sed -i '/#!\/usr\/bin\/env/d' {} \;

# Get the .desktop files ready
mv examples/IPython\ Kernel/*.desktop ./
sed -i 's/gnome-netstatus-idle/ipython/g' *.desktop
sed -i 's/Exec=ipython/Exec=ipython-%{py_ver}/g' *.desktop
mv ipython.desktop ipython-%{py_ver}.desktop
mv ipython-qtconsole.desktop ipython-qtconsole-%{py_ver}.desktop

%build
export CFLAGS="%{optflags}"
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

install -d -m 755 %{buildroot}%{_docdir}/

# docs now require jsdoc, a javascript package
# make docs
# pushd docs
# PYTHONPATH=$PYTHONPATH:%{buildroot}%{python_sitelib} make html
# rm build/html/.buildinfo
# mv build/html %{buildroot}%{_docdir}/%{name}/
# popd
# add examples
cp -vr examples %{buildroot}%{_docdir}/%{name}/

# set executable
chmod a+x %{buildroot}%{python_sitelib}/%{name}/external/mathjax.py

# remove all executables that end in *2
rm %{buildroot}/%{_bindir}/ipcluster2
rm %{buildroot}/%{_bindir}/ipcontroller2
rm %{buildroot}/%{_bindir}/ipengine2
rm %{buildroot}/%{_bindir}/iptest2
rm %{buildroot}/%{_bindir}/ipython2

# remove hidden files
rm -f %{buildroot}%{python_sitelib}/%{name}/.git_commit_info.ini
rm -f %{buildroot}%{python_sitelib}/%{name}/html/static/components/.gitignore
rm -f %{buildroot}%{_docdir}/%{name}/manual/.buildinfo

%fdupes %{buildroot}%{_docdir}/%{name}/

# install .desktop files
%suse_update_desktop_file -r -i ipython-%{py_ver} System TerminalEmulator
%suse_update_desktop_file -r -i ipython-qtconsole-%{py_ver} System TerminalEmulator

# install icons
tar xf %{S:1} -C %{buildroot}%{_datadir}

# Prepare for update-alternatives usage
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
for p in ipython iptest ipengine ipcontroller ipcluster ; do
    mv %{buildroot}%{_bindir}/$p %{buildroot}%{_bindir}/$p-%{py_ver}
    ln -s -f %{_sysconfdir}/alternatives/$p %{buildroot}%{_bindir}/$p
    # create a dummy target for /etc/alternatives/$p
    touch %{buildroot}%{_sysconfdir}/alternatives/$p
done

# Prepare for update-alternatives usage
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
for p in ipython ipengine ipcontroller ipcluster ; do
    mv %{buildroot}%{_mandir}/man1/$p.1 %{buildroot}%{_mandir}/man1/$p-%{py_ver}.1
    ln -s -f %{_sysconfdir}/alternatives/$p.1.gz %{buildroot}%{_mandir}/man1/$p.1.gz
    # create a dummy target for /etc/alternatives/$p
    touch %{buildroot}%{_sysconfdir}/alternatives/$p.1.gz
done

%post
%_sbindir/update-alternatives \
   --install %{_bindir}/ipython ipython %{_bindir}/ipython-%{py_ver} 30 \
   --slave %{_bindir}/iptest iptest %{_bindir}/iptest-%{py_ver} \
   --slave %{_bindir}/ipengine ipengine %{_bindir}/ipengine-%{py_ver} \
   --slave %{_bindir}/ipcontroller ipcontroller %{_bindir}/ipcontroller-%{py_ver} \
   --slave %{_bindir}/ipcluster ipcluster %{_bindir}/ipcluster-%{py_ver} \
   --slave %{_mandir}/man1/ipython.1.gz ipython.1.gz %{_mandir}/man1/ipython-%{py_ver}.1.gz \
   --slave %{_mandir}/man1/ipengine.1.gz ipengine.1.gz %{_mandir}/man1/ipengine-%{py_ver}.1.gz \
   --slave %{_mandir}/man1/ipcontroller.1.gz ipcontroller.1.gz %{_mandir}/man1/ipcontroller-%{py_ver}.1.gz \
   --slave %{_mandir}/man1/ipcluster.1.gz ipcluster.1.gz %{_mandir}/man1/ipcluster-%{py_ver}.1.gz

%postun
if [ $1 -eq 0 ] ; then
    %_sbindir/update-alternatives --remove ipython %{_bindir}/ipython-%{py_ver}
fi

%files
%defattr(-,root,root)
%doc COPYING.rst README.rst
%{_bindir}/ipcluster
%{_bindir}/ipcontroller
%{_bindir}/ipengine
%{_bindir}/iptest
%{_bindir}/ipython
%{_bindir}/ipcluster-%{py_ver}
%{_bindir}/ipcontroller-%{py_ver}
%{_bindir}/ipengine-%{py_ver}
%{_bindir}/iptest-%{py_ver}
%{_bindir}/ipython-%{py_ver}
%{_mandir}/man1/ipcluster.1.gz
%{_mandir}/man1/ipcontroller.1.gz
%{_mandir}/man1/ipengine.1.gz
%{_mandir}/man1/ipython.1.gz
%{_mandir}/man1/ipcluster-%{py_ver}.1.gz
%{_mandir}/man1/ipcontroller-%{py_ver}.1.gz
%{_mandir}/man1/ipengine-%{py_ver}.1.gz
%{_mandir}/man1/ipython-%{py_ver}.1.gz
%ghost %{_sysconfdir}/alternatives/ipcluster
%ghost %{_sysconfdir}/alternatives/ipcontroller
%ghost %{_sysconfdir}/alternatives/ipengine
%ghost %{_sysconfdir}/alternatives/iptest
%ghost %{_sysconfdir}/alternatives/ipython
%ghost %{_sysconfdir}/alternatives/ipcluster.1.gz
%ghost %{_sysconfdir}/alternatives/ipcontroller.1.gz
%ghost %{_sysconfdir}/alternatives/ipengine.1.gz
%ghost %{_sysconfdir}/alternatives/ipython.1.gz
%{_datadir}/applications/ipython-qtconsole-%{py_ver}.desktop
%{_datadir}/applications/ipython-%{py_ver}.desktop
%{_datadir}/icons/hicolor/
%{python_sitelib}/%{name}
%{python_sitelib}/ipython-%{version}-py*.egg-info
%exclude %{_docdir}/%{name}/

%files doc
%defattr(-,root,root)
%{_docdir}/%{name}/
%exclude %{_docdir}/%{name}/COPYING.rst
%exclude %{_docdir}/%{name}/README.rst

%changelog
* Wed Sep 23 2015 toddrme2178@gmail.com
- Update to 3.2.2
  * This is a critical security update.
    Addresses vulnerabilities when files have maliciously crafted filenames (CVE-2015-6938),
    or vulnerability when opening text files with malicious binary content (CVE pending).
* Mon Aug 31 2015 toddrme2178@gmail.com
- Implement update-alternatives
  This avoids a conflict with the python3 version of the new
  jupyter packages.  The python3 version of jupyter should not
  conflict with the python2 versions of IPython.
* Mon Jul 13 2015 arun@gmx.de
- update to version 3.2.1:
  * IPython 3.2.1 is a small bugfix release, primarily for cross-site
    security fixes in the notebook. Users are strongly encouraged to
    upgrade immediately. There are also a few small unicode and
    nbconvert-related fixes
* Wed Jul  1 2015 toddrme2178@gmail.com
- update to version 3.2.0:
  * IPython 3.2 contains important security fixes. Users are
    strongly encouraged to upgrade immediately.
  * Highlights:
  - A security improvement that set the secure attribute to login cookie to prevent them to be sent over http
  - Revert the face color of matplotlib axes in the inline backend to not be transparent.
  - Enable mathjax safe mode by default
  - Fix XSS vulnerability in JSON error messages
  - Various widget-related fixes
- update to version 3.1.0:
  * Highlights:
    + Various focus jumping and scrolling fixes in the notebook.
    + Various message ordering and widget fixes in the notebook.
    + Images in markdown and output are confined to the notebook
    width. An .unconfined CSS class is added to disable this
    behavior per-image. The resize handle on output images is
    removed.
    + Improved ordering of tooltip content for Python functions,
    putting the signature at the top.
    + Fix UnicodeErrors when displaying some objects with unicode
    reprs on Python 2.
    + Set the kernel’s working directory to the notebook directory
    when running nbconvert --execute, so that behavior matches the
    live notebook.
    + Allow setting custom SSL options for the tornado server with
    NotebookApp.ssl_options, and protect against POODLE with default
    settings by disabling SSLv3.
    + Fix memory leak in the IPython.parallel Controller on Python 3.
  * See Issues closed in the 3.x development cycle for details.
- Don't depend on wxwidgets for SLES 12
* Mon Mar  2 2015 toddrme2178@gmail.com
- specfile:
  * added mistune, jsonschema requirement
  * updated some version numbers for requirements
  * removed pandoc requirement
  * no longer build html documentation.  This requires the jsdoc
    package, which is not available from OBS and appears
    complicated to set up.
- update to version 3.0.0:
  * Using different kernels
  * typing unicode identifiers
  * new widgets
  * lots of other changes, see
    http://ipython.org/ipython-doc/3/whatsnew/version3.html
* Sat Jan  3 2015 arun@gmx.de
- specfile:
  * updated copyright year
  * added Jinja2 requirement for notebook and nbconvert (bnc#911524)
* Mon Oct 13 2014 toddrme2178@gmail.com
- Update to 2.3.0
  * Bugfix release
* Sat Aug 30 2014 dimstar@opensuse.org
- Drop gnome-icon-theme BuildRequires: the theme no longer exists
  (it was merged and renamed to Adwaita-icon-theme). Instead,
  package the icons in a tarball and install them during build.
* Thu Aug 28 2014 toddrme2178@gmail.com
- Add pandoc dependency for nbconvert notebook converter.
  This is only available for openSUSE > 13.1.
- Change some dependencies that are not required for basic
  functionality to Recommends.
* Sat Aug  9 2014 toddrme2178@gmail.com
- Update to 2.2.0
  * Bugfix release
* Tue Jul 15 2014 toddrme2178@gmail.com
- Update to 2.1.0
  * Bugfix release
* Thu May  8 2014 hpj@urpla.net
- add examples to -doc package
* Thu Apr  3 2014 arun@gmx.de
- updated to 2.0.0
  The principal milestones of 2.0 are:
  * interactive widgets for the notebook
  * directory navigation in the notebook dashboard
  * persistent URLs for notebooks
  * a new modal user interface in the notebook
  * a security model for notebooks
  more details at http://ipython.org/ipython-doc/2/whatsnew/version2.0.html
  * changes in spec file:
  - manual remove binaries that end in *2
  - added dependencies matplotlib, numpydoc, updated version for tornado
  - logger, color and irunner are not provided anymore, remove from file list
  - Copying is now in rst format
  - name and location of desktop files changed
* Fri Mar  7 2014 arun@gmx.de
- - update to 1.2.1 (including 1.2.0)
  Pull Requests (38):
  1.2.1:
    PR #4372: Don’t assume that SyntaxTB is always called with a SyntaxError
    PR #5166: remove mktemp usage
    PR #5163: Simplify implementation of TemporaryWorkingDirectory.
    PR #5105: add index to format to support py2.6
  1.2.0:
    PR #4972: Work around problem in doctest discovery in Python 3.4 with PyQt
    PR #4934: ipython profile create respects –ipython-dir
    PR #4845: Add Origin Checking.
    PR #4928: use importlib.machinery when available
    PR #4849: Various unicode fixes (mostly on Windows)
    PR #4880: set profile name from profile_dir
    PR #4908: detect builtin docstrings in oinspect
    PR #4909: sort dictionary keys before comparison, ordering is not guaranteed
    PR #4903: use https for all embeds
    PR #4868: Static path fixes
    PR #4820: fix regex for cleaning old logs with ipcluster
    PR #4840: Error in Session.send_raw()
    PR #4762: whitelist alphanumeric characters for cookie_name
    PR #4748: fix race condition in profiledir creation.
    PR #4720: never use ssh multiplexer in tunnels
    PR #4738: don’t inject help into user_ns
    PR #4722: allow purging local results as long as they are not outstanding
    PR #4668: Make non-ASCII docstring unicode
    PR #4639: Minor import fix to get qtconsole with –pylab=qt working
    PR #4453: Play nice with App Nap
    PR #4609: Fix bytes regex for Python 3.
    PR #4488: fix typo in message spec doc
    PR #4346: getpass() on Windows & Python 2 needs bytes prompt
    PR #4230: Switch correctly to the user’s default matplotlib backend after inline.
    PR #4214: engine ID metadata should be unicode, not bytes
    PR #4232: no highlight if no language specified
    PR #4218: Fix display of SyntaxError when .py file is modified
    PR #4217: avoid importing numpy at the module level
    PR #4213: fixed dead link in examples/notebooks readme to Part 3
    PR #4183: ESC should be handled by CM if tooltip is not on
    PR #4193: Update for #3549: Append Firefox overflow-x fix
    PR #4205: use TextIOWrapper when communicating with pandoc subprocess
    PR #4204: remove some extraneous print statements from IPython.parallel
    PR #4201: HeadingCells cannot be split or merged
  Issues (17):
  1.2.1:
    [#5101]: IPython 1.2.0: notebook fail with “500 Internal Server Error”
  1.2.0:
    [#4892]: IPython.qt test failure with python3.4
    [#4810]: ipcluster bug in clean_logs flag
    [#4765]: missing build script for highlight.js
    [#4761]: ipv6 address triggers cookie exception
    [#4721]: purge_results with jobid crashing - looking for insight
    [#4602]: “ipcluster stop” fails after “ipcluster start –daemonize” using python3.3
    [#3386]: Magic %%paste not working in Python 3.3.2. TypeError: Type str doesn’t support the buffer API
    [#4485]: Incorrect info in “Messaging in IPython” documentation.
    [#4351]: /parallel/apps/launcher.py error
    [#4334]: NotebookApp.webapp_settings static_url_prefix causes crash
    [#4039]: Celltoolbar example issue
    [#4256]: IPython no longer handles unicode file names
    [#4122]: Nbconvert [windows]: Inconsistent line endings in markdown cells exported to latex
    [#3819]: nbconvert add extra blank line to code block on Windows.
    [#4203]: remove spurious print statement from parallel annoted functions
    [#4200]: Notebook: merging a heading cell and markdown cell cannot be undone
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Oct  8 2013 toddrme2178@gmail.com
- Update to 1.1.0
  * Bugfixes
- Fix building on openSUSE 12.2
* Fri Aug  9 2013 tzotsos@opensuse.org
- update to 1.0.0
- The principal milestone is the addition of IPython.nbconvert.
- Added IPython.kernel for all kernel-related code.
- Removed the frontend subpackage, as it caused unnecessary depth.
- The IPython sphinx directives are now installed in IPython.sphinx.
- The input transformation framework has been reworked.
- Exception types can now be displayed with a custom traceback.
- A new command, ipython history trim can be used to delete everything but the last 1000 entries in the history database.
- __file__ is defined in both config files at load time, and .ipy files executed with %%run.
- %%logstart and %%logappend are no longer broken.
- Add glob expansion for %%run, e.g. %%run -g script.py *.txt.
- Expand variables ($foo) in Cell Magic argument line.
- By default, iptest will exclude various slow tests. All tests can be run with iptest –all.
- SQLite history can be disabled in the various cases that it does not behave well.
- %%edit works on interactively defined variables.
- editor hooks have been restored from quarantine, enabling TextMate as editor, etc.
- The env variable PYTHONSTARTUP is respected by IPython.
- The %%matplotlib magic was added.
- The --matplotlib command line flag was also added.
* Wed Jun  5 2013 toddrme2178@gmail.com
- Install .desktop files
- Add buildrequires so there is proper detection of dependencies
  at build-time
- Add python-distribute buildrequires for proper dependency
  detection
- Build full documentation in python 2 version
  (not yet working with python 3)
- Include license file and README file
- Change suggests to recommends since suggests are not well
  supported
- Manually-specify executable and manual file names to better
  identify conflicts between python 2 and python 3 versions
* Fri May 17 2013 jmatejek@suse.com
- update to 0.13.2
  - bugfix-release, 52 bugs fixed
  - improved compatibility with new Qt versions
    (fixes bnc#819931, obsoletes ipython-fix-loading-newer-pyqt.diff)
- drop conditionals for too-old SUSE releases
- shorten summary
* Fri Mar 15 2013 lbeltrame@kde.org
- Add ipython-fix-loading-newer-pyqt.diff to make Qt console
  load with PyQt 4.10 (fix already upstream)
* Wed Jan  2 2013 toddrme2178@gmail.com
- Fix building on SLES
* Wed Oct 24 2012 einar@heavensinferno.net
- Update to 0.13.1
  - New major upstream release
  - Major notebook improvements
  - Major improvements to the Qt console
  - Improvement of parallel tools
* Thu May  3 2012 cfarrell@suse.com
- license update: BSD-3-Clause
  See http://ipython.org/ipython-doc/dev/about/license_and_copyright.html
* Mon Apr 30 2012 toddrme2178@gmail.com
- Fix building python 3 package on openSUSE 11.4 x86_64
* Sat Apr 28 2012 highwaystar.ru@gmail.com
- added python-tornado Requires for ipython notebook mode
* Fri Apr 27 2012 toddrme2178@gmail.com
- Update to 0.12.1
  Bugfixes
- Comment out non-existant wxpython-related python 3 packages
- Change python 3 binary names so they don't conflict with the
  python 2 ones
- Fix removal of hidden git info in python3 package
- Small python 2 package spec file cleanups
* Fri Apr 27 2012 highwaystar.ru@gmail.com
- added build dependency python3-2to3
  without it files just not converted silently
* Thu Feb  9 2012 highwaystar.ru@gmail.com
- added python3-IPython package
* Wed Feb  8 2012 einar@heavensinferno.net
- updated to 0.12
  IPython 0.12 contains several major new features, as well as a large amount
  of bug and regression fixes.
  New features:
  * An interactive browser-based Notebook with rich media support
  * Two-process terminal console
  * Tabbed QtConsole
  * Full Python 3 compatibility
  * Standalone Kernel
  * PyPy support
* Sun Jul 31 2011 ocefpaf@yahoo.com.br
- updated to 0.11
  IPython 0.11 is a *major* overhaul of IPython, two years in the making.  Most
  of the code base has been rewritten or at least reorganized, breaking backward
  compatibility with several APIs in previous versions.
  Since the internal APIs have changed so much, projects using IPython as a
  library (as opposed to end-users of the application) are the most likely to
  encounter regressions or changes that break their existing use patterns.
  A quick summary:
  * Standalone Qt console.
  * High-level parallel computing with ZeroMQ.
  * New model for GUI/plotting support in the terminal.
  * A two-process architecture.
  * Vim integration.
  * Integration into Microsoft Visual Studio
  * Improved unicode support.
  * Python 3 support.
  * New profile model.
  * SQLite storage for history.
  * New configuration system.
  * Pasting of code with prompts.
* Sat Jul 16 2011 ocefpaf@yahoo.com.br
- updated to 0.10.2
  * This is a minor bugfix and latst release of the 0.10.x series.
  * Closing of github ticket #185, a major regression we had
    in 0.10.1 where pylab mode with GTK was not working correctly,
    hence plots were blocking with GTK.  Since this is the default matplotlib
    backend on Unix systems, this was a major annoyance for many users.  Many
    thanks to Paul Ivanov for helping resolve this issue.
  * Fix IOError bug on Windows when used with -gthread.
  * Work robustly if $HOME is missing from environment.
  * Better POSIX support in ssh scripts (remove bash-specific idioms).
  * Improved support for non-ascii characters in log files.
  * Work correctly in environments where GTK can be imported but not started
    (such as a linux text console without X11).
* Wed Dec 29 2010 sbrabec@suse.cz
- Updated python-wxWidgets name.
* Tue Aug 11 2009 matejcik@suse.cz
- removed useless item from filelist
- switched to noarch
* Sun Aug  9 2009 coolo@novell.com
- new new python macros
* Wed Aug  5 2009 matejcik@suse.cz
- update to 0.10
  * lots of bugfixes
  * improved gui and wx-based gui component
  * improved ipcluster
- split off -doc subpackage
* Wed Sep 10 2008 matejcik@suse.cz
- update to 0.8.4
  * support for Leo
  * improved multithreading
  * better %%edit
  * new extensions
  * better wx GUI
* Fri Mar 14 2008 matejcik@suse.cz
- update to 0.8.2
  * "shadow history" remembers every command forever
  * macros with arguments
  * various new extensions
  * various new features and bugfixes
* Wed Jul 25 2007 jmatejek@suse.cz
- update to 0.8.1
  * fully syntax highlighted tracebacks
  * support for Ctrl+C while multithreading
  * improved unicode support
  * various new features and bugfixes
* Thu Oct 19 2006 jmatejek@suse.cz
- update to 0.7.2
- many new features: extension API, better persistence,
  script runner, IPipe tabular data navigator, simplified
  output capturing etc.
* Tue Feb 28 2006 jmatejek@suse.cz
- updated to reflect python changes due to #149809
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Oct 10 2005 matejcik@suse.cz
- update to 0.6.15
* Wed Oct  5 2005 dmueller@suse.de
- add norootforbuild
* Wed Feb 16 2005 mcihar@suse.cz
- update to 0.6.11
* Tue Dec 21 2004 mcihar@suse.cz
- update to 0.6.6
* Wed Sep  1 2004 mcihar@suse.cz
- update to 0.6.3
* Tue Aug  3 2004 mcihar@suse.cz
- update to 0.6.2
- use py_requires macro
* Mon Oct 13 2003 mcihar@suse.cz
- versioned python dependency
- fixed build on lib64 arches
* Mon Oct 13 2003 mcihar@suse.cz
- created new package
